@@ -71,13 +71,9 @@ pub fn generate(enum_args: &args::Enum) -> GeneratorResult<TokenStream> {
     }
 
     let remote_conversion = if let Some(remote) = &enum_args.remote {
-        let remote_ty = if let Ok(ty) = syn::parse_str::<syn::Type>(remote) {
-            ty
-        } else {
-            return Err(
-                Error::new_spanned(remote, format!("Invalid remote type: '{}'", remote)).into(),
-            );
-        };
+        let remote_ty = syn::parse_str::<syn::Type>(remote).map_err(|_| {
+            Error::new_spanned(remote, format!("Invalid remote type: '{}'", remote))
+        })?;
 
         let local_to_remote_items = enum_items.iter().map(|item| {
             quote! {
